@@ -22,9 +22,6 @@
 #include "../lagrange/p23d.hh"
 #include "../lagrange/pq22d.hh"
 #include "../lagrange/pk.hh"
-#if !DISABLE_DEPRECATED_METHOD_CHECK
-#include "../lagrange/q2.hh"
-#endif
 #include "../lagrange/qk.hh"
 
 #include "../brezzidouglasmarini/brezzidouglasmarini1cube2d.hh"
@@ -41,7 +38,7 @@
 #include "../rannacherturek/rannacherturek.hh"
 #include "../raviartthomas/raviartthomassimplex.hh"
 #include "../raviartthomas/raviartthomascube.hh"
-#include "../monom.hh"
+#include "../monomial.hh"
 
 #include "../common/virtualinterface.hh"
 #include "../common/virtualwrappers.hh"
@@ -57,7 +54,7 @@ struct PkLocalFiniteElementTest
     bool success = true;
 
     Dune::PkLocalFiniteElement<double,double,d,k> pklfem;
-    success = testFE(pklfem) and success;
+    TEST_FE(pklfem);
 
     return PkLocalFiniteElementTest<d, k-1>::test() and success;
   }
@@ -79,16 +76,16 @@ bool testMonomials()
   Dune::GeometryType gt;
 
   gt.makeLine();
-  Dune::MonomLocalFiniteElement<double,double,1,k> monom1d(gt);
-  success = testFE(monom1d) and success;
+  Dune::MonomialLocalFiniteElement<double,double,1,k> monom1d(gt);
+  TEST_FE(monom1d);
 
   gt.makeTriangle();
-  Dune::MonomLocalFiniteElement<double,double,2,k> monom2d(gt);
-  success = testFE(monom2d) and success;
+  Dune::MonomialLocalFiniteElement<double,double,2,k> monom2d(gt);
+  TEST_FE(monom2d);
 
   gt.makeTetrahedron();
-  Dune::MonomLocalFiniteElement<double,double,3,k> monom3d(gt);
-  success = testFE(monom3d) and success;
+  Dune::MonomialLocalFiniteElement<double,double,3,k> monom3d(gt);
+  TEST_FE(monom3d);
 
   return testMonomials<k-1>() and success;
 }
@@ -105,95 +102,95 @@ int main(int argc, char** argv) try
 
   Dune::P0LocalFiniteElement<double,double,2> p0lfem(
     Dune::GeometryType(Dune::GeometryType::simplex, 2));
-  success = testFE(p0lfem) and success;
+  TEST_FE(p0lfem);
 
   Dune::P1LocalFiniteElement<double,double,1> p11dlfem;
-  success = testFE(p11dlfem) and success;
+  TEST_FE(p11dlfem);
 
   Dune::P1LocalFiniteElement<double,double,2> p12dlfem;
-  success = testFE(p12dlfem) and success;
+  TEST_FE(p12dlfem);
 
   Dune::P1LocalFiniteElement<double,double,3> p13dlfem;
-  success = testFE(p13dlfem) and success;
+  TEST_FE(p13dlfem);
 
   Dune::Q1LocalFiniteElement<double,double,1> q11dlfem;
-  success = testFE(q11dlfem) and success;
+  TEST_FE(q11dlfem);
 
   Dune::Q1LocalFiniteElement<double,double,2> q12dlfem;
-  success = testFE(q12dlfem) and success;
+  TEST_FE(q12dlfem);
 
   Dune::Q1LocalFiniteElement<double,double,3> q13dlfem;
-  success = testFE(q13dlfem) and success;
+  TEST_FE(q13dlfem);
 
   Dune::PQ22DLocalFiniteElement<double,double> pq22dlfem(
     Dune::GeometryType( Dune::GeometryType::simplex,2) );
-  success = testFE(pq22dlfem) and success;
+  TEST_FE(pq22dlfem);
 
   Dune::RefinedP1LocalFiniteElement<double,double,1> refp11dlfem;
-  success = testFE(refp11dlfem) and success;
+  TEST_FE(refp11dlfem);
 
   Dune::RefinedP1LocalFiniteElement<double,double,2> refp12dlfem;
-  success = testFE(refp12dlfem) and success;
+  TEST_FE(refp12dlfem);
 
   Dune::RefinedP1LocalFiniteElement<double,double,3> refp13dlfem;
-  success = testFE(refp13dlfem) and success;
+  TEST_FE(refp13dlfem);
 
   Dune::RefinedP0LocalFiniteElement<double,double,1> refp01dlfem;
-  success = testFE(refp01dlfem) and success;
+  TEST_FE(refp01dlfem);
 
   Dune::RefinedP0LocalFiniteElement<double,double,2> refp02dlfem;
-  success = testFE(refp02dlfem) and success;
+  TEST_FE(refp02dlfem);
 
   Dune::P23DLocalFiniteElement<double,double> p23dlfem;
-  success = testFE(p23dlfem) and success;
+  TEST_FE(p23dlfem);
 
   // --------------------------------------------------------
   //  Test Brezzi-Douglas-Marini finite elements
   // --------------------------------------------------------
   Dune::BDM1Cube2DLocalFiniteElement<double,double> bdm1cube2dlfem(1);
-  success = testFE(bdm1cube2dlfem) and success;
+  TEST_FE(bdm1cube2dlfem);
 
   Dune::BDM1Cube3DLocalFiniteElement<double,double> bdm1cube3dlfem(1);
-  success &= testFE(bdm1cube3dlfem, DisableLocalInterpolation);
+  TEST_FE2(bdm1cube3dlfem, DisableLocalInterpolation);
 
   Dune::BDM2Cube2DLocalFiniteElement<double,double> bdm2cube2dlfem(1);
-  success &= testFE(bdm2cube2dlfem);
+  TEST_FE(bdm2cube2dlfem);
 
   Dune::BDM1Simplex2DLocalFiniteElement<double,double> bdm1simplex2dlfem(1);
-  success = testFE(bdm1simplex2dlfem) and success;
+  TEST_FE(bdm1simplex2dlfem);
 
   Dune::BDM2Simplex2DLocalFiniteElement<double,double> bdm2simplex2dlfem(1);
-  success &= testFE(bdm2simplex2dlfem, DisableLocalInterpolation);
+  TEST_FE2(bdm2simplex2dlfem, DisableLocalInterpolation);
 
   // --------------------------------------------------------
   //  Test hierarchical P2 finite elements
   // --------------------------------------------------------
   Dune::HierarchicalP2LocalFiniteElement<double,double,1> hierarchicalp21dlfem;
-  success = testFE(hierarchicalp21dlfem) and success;
+  TEST_FE(hierarchicalp21dlfem);
 
   Dune::HierarchicalP2LocalFiniteElement<double,double,2> hierarchicalp22dlfem;
-  success = testFE(hierarchicalp22dlfem) and success;
+  TEST_FE(hierarchicalp22dlfem);
 
   Dune::HierarchicalP2LocalFiniteElement<double,double,3> hierarchicalp23dlfem;
-  success = testFE(hierarchicalp23dlfem) and success;
+  TEST_FE(hierarchicalp23dlfem);
 
   Dune::HierarchicalPrismP2LocalFiniteElement<double,double> hierarchicalprismp2lfem;
-  success = testFE(hierarchicalprismp2lfem) and success;
+  TEST_FE(hierarchicalprismp2lfem);
 
   Dune::HierarchicalP2WithElementBubbleLocalFiniteElement<double,double,2> hierarchicalp2bubble2dlfem;
-  success = testFE(hierarchicalp2bubble2dlfem) and success;
+  TEST_FE(hierarchicalp2bubble2dlfem);
 
   Dune::PrismP1LocalFiniteElement<double,double> prismp1fem;
-  success = testFE(prismp1fem) and success;
+  TEST_FE(prismp1fem);
 
   Dune::PrismP2LocalFiniteElement<double,double> prismp2fem;
-  success = testFE(prismp2fem) and success;
+  TEST_FE(prismp2fem);
 
   Dune::PyramidP1LocalFiniteElement<double,double> pyramidp1fem;
-  success = testFE(pyramidp1fem, DisableJacobian) and success;
+  TEST_FE2(pyramidp1fem, DisableJacobian);
 
   Dune::PyramidP2LocalFiniteElement<double,double> pyramidp2fem;
-  success = testFE(pyramidp2fem, DisableJacobian) and success;
+  TEST_FE2(pyramidp2fem, DisableJacobian);
 
   success = PkLocalFiniteElementTest<1, 1>::test() and success;
 
@@ -203,93 +200,97 @@ int main(int argc, char** argv) try
 
   success = PkLocalFiniteElementTest<3, 10>::test() and success;
 
-#if !DISABLE_DEPRECATED_METHOD_CHECK
-  Dune::Q2LocalFiniteElement<double,double,1> q21dlfem;
-  success = testFE(q21dlfem) and success;
-
-  Dune::Q2LocalFiniteElement<double,double,2> q22dlfem;
-  success = testFE(q22dlfem) and success;
-
-  Dune::Q2LocalFiniteElement<double,double,3> q23dlfem;
-  success = testFE(q23dlfem) and success;
-#endif
-
   // --------------------------------------------------------
   //  Test some instantiations of QkLocalFiniteElement
   // --------------------------------------------------------
   Dune::QkLocalFiniteElement<double,double,1,1> qk11dlfem;
-  success = testFE(qk11dlfem) and success;
+  TEST_FE(qk11dlfem);
+
+  Dune::QkLocalFiniteElement<double,double,2,0> qk02dlfem;
+  TEST_FE(qk02dlfem);
 
   Dune::QkLocalFiniteElement<double,double,2,1> qk12dlfem;
-  success = testFE(qk12dlfem) and success;
+  TEST_FE(qk12dlfem);
 
   Dune::QkLocalFiniteElement<double,double,2,2> qk22dlfem;
-  success = testFE(qk22dlfem) and success;
+  TEST_FE(qk22dlfem);
 
   Dune::QkLocalFiniteElement<double,double,2,3> qk32dlfem;
-  success = testFE(qk32dlfem) and success;
+  TEST_FE(qk32dlfem);
+
+  Dune::QkLocalFiniteElement<double,double,3,0> qk03dlfem;
+  TEST_FE(qk03dlfem);
 
   Dune::QkLocalFiniteElement<double,double,3,1> qk13dlfem;
-  success = testFE(qk13dlfem) and success;
+  TEST_FE(qk13dlfem);
 
   Dune::QkLocalFiniteElement<double,double,3,2> qk23dlfem;
-  success = testFE(qk23dlfem) and success;
+  TEST_FE(qk23dlfem);
 
   Dune::QkLocalFiniteElement<double,double,3,3> qk33dlfem;
-  success = testFE(qk33dlfem) and success;
+  TEST_FE(qk33dlfem);
 
 
   // --------------------------------------------------------
   //  Test dual mortar elements
   // --------------------------------------------------------
   Dune::DualP1LocalFiniteElement<double,double,1> dualp11dlfem;
-  success = testFE(dualp11dlfem) and success;
+  TEST_FE(dualp11dlfem);
 
   Dune::DualP1LocalFiniteElement<double,double,2> dualp12dlfem;
-  success = testFE(dualp12dlfem) and success;
+  TEST_FE(dualp12dlfem);
 
   Dune::DualP1LocalFiniteElement<double,double,3> dualp13dlfem;
-  success = testFE(dualp13dlfem) and success;
+  TEST_FE(dualp13dlfem);
 
   Dune::DualQ1LocalFiniteElement<double,double,1> dualq11dlfem;
-  success = testFE(dualq11dlfem) and success;
+  TEST_FE(dualq11dlfem);
 
   Dune::DualQ1LocalFiniteElement<double,double,2> dualq12dlfem;
-  success = testFE(dualq12dlfem) and success;
+  TEST_FE(dualq12dlfem);
 
   Dune::DualQ1LocalFiniteElement<double,double,3> dualq13dlfem;
-  success = testFE(dualq13dlfem) and success;
+  TEST_FE(dualq13dlfem);
 
 
   // --------------------------------------------------------
   //  Test Raviart-Thomas Finite elements
   // --------------------------------------------------------
   Dune::RaviartThomasSimplexLocalFiniteElement<2,double,double> rt0simplex2dlfem(Dune::GeometryType(Dune::GeometryType::simplex,2),0);
-  success = testFE(rt0simplex2dlfem) and success;
+  TEST_FE(rt0simplex2dlfem);
 
   Dune::RaviartThomasSimplexLocalFiniteElement<2,double,double> rt1simplex2dlfem(Dune::GeometryType(Dune::GeometryType::simplex,2),1);
-  success = testFE(rt1simplex2dlfem) and success;
+  TEST_FE(rt1simplex2dlfem);
 
   Dune::RaviartThomasCubeLocalFiniteElement<double,double,2,0> rt0cube2dlfem(1);
-  success = testFE(rt0cube2dlfem) and success;
+  TEST_FE(rt0cube2dlfem);
 
   Dune::RaviartThomasCubeLocalFiniteElement<double,double,3,0> rt0cube3dlfem(1);
-  success = testFE(rt0cube3dlfem) and success;
+  TEST_FE(rt0cube3dlfem);
 
   Dune::RaviartThomasCubeLocalFiniteElement<double,double,2,1> rt1cube2dlfem(1);
-  success = testFE(rt1cube2dlfem) and success;
+  TEST_FE(rt1cube2dlfem);
 
   Dune::RaviartThomasCubeLocalFiniteElement<double,double,3,1> rt1cube3dlfem(1);
-  success = testFE(rt1cube3dlfem) and success;
+  TEST_FE(rt1cube3dlfem);
 
   Dune::RaviartThomasCubeLocalFiniteElement<double,double,2,2> rt2cube2dlfem(1);
-  success = testFE(rt2cube2dlfem) and success;
+  TEST_FE(rt2cube2dlfem);
 
+  Dune::RaviartThomasCubeLocalFiniteElement<double,double,2,3> rt3cube2dlfem(1);
+  TEST_FE2(rt3cube2dlfem, DisableJacobian);
+
+  Dune::RaviartThomasCubeLocalFiniteElement<double,double,2,4> rt4cube2dlfem(1);
+  TEST_FE2(rt4cube2dlfem, DisableJacobian);
+
+  // --------------------------------------------------------
+  //  Test Rannacher-Turek Finite elements
+  // --------------------------------------------------------
   Dune::RannacherTurekLocalFiniteElement<double,double,2> rannacher_turek2dfem;
-  success = testFE(rannacher_turek2dfem) and success;
+  TEST_FE(rannacher_turek2dfem);
 
   Dune::RannacherTurekLocalFiniteElement<double,double,3> rannacher_turek3dfem;
-  success = testFE(rannacher_turek3dfem) and success;
+  TEST_FE(rannacher_turek3dfem);
 
   std::cout << "Monomials are only tested up to order 2 due to the instability of interpolate()." << std::endl;
   success = testMonomials<2>() and success;
@@ -298,26 +299,26 @@ int main(int argc, char** argv) try
   // notice that testFE add another level of virtualization
   Dune::LocalFiniteElementVirtualImp< Dune::P1LocalFiniteElement<double,double, 2> >
   p12dlfemVirtual(p12dlfem);
-  success = testFE(p12dlfemVirtual) and success;
+  TEST_FE(p12dlfemVirtual);
 
   Dune::LocalFiniteElementVirtualImp< Dune::PQ22DLocalFiniteElement<double,double> >
   pq22dlfemVirtual(pq22dlfem);
-  success = testFE(pq22dlfemVirtual) and success;
+  TEST_FE(pq22dlfemVirtual);
 
   Dune::LocalFiniteElementVirtualImp<
       Dune::LocalFiniteElementVirtualImp<
           Dune::P1LocalFiniteElement<double,double, 2> > >
   p12dlfemVirtualVirtual(p12dlfemVirtual);
-  success = testFE(p12dlfemVirtualVirtual) and success;
+  TEST_FE(p12dlfemVirtualVirtual);
 
   Dune::LocalFiniteElementVirtualImp<
       Dune::LocalFiniteElementVirtualImp<
           Dune::PQ22DLocalFiniteElement<double,double> > >
   pq22dlfemVirtualVirtual(pq22dlfemVirtual);
-  success = testFE(pq22dlfemVirtualVirtual) and success;
+  TEST_FE(pq22dlfemVirtualVirtual);
 
   typedef Dune::LocalFiniteElementVirtualInterface< Dune::P1LocalFiniteElement<double,double, 2>::Traits::LocalBasisType::Traits > Interface;
-  success = testFE<Interface>(p12dlfemVirtual) and success;
+  TEST_FE(static_cast<const Interface&>(p12dlfemVirtual));
 
   return success ? 0 : 1;
 }
